@@ -49,6 +49,7 @@ from .remote import RemoteCollection
 from .blame import Blame
 from .utils import to_bytes, StrArray
 from .submodule import Submodule
+from .packbuilder import PackBuilder
 
 
 class BaseRepository(_Repository):
@@ -83,6 +84,39 @@ class BaseRepository(_Repository):
         object."""
         return self.odb.write(*args, **kwargs)
 
+    def pack(self, path=None, pack_delegate=None, n_threads=None):
+        """Pack the objects in the odb chosen by the pack_delegate function
+        and write .pack and .idx files for them.
+
+        Returns: the number of objects written to the pack
+
+        Parameters:
+
+        path
+            The path to which the .pack and .idx files should be written. None will write to the default location.
+
+        pack_delegate
+            The method which will provide add the objects to the pack builder. Defaults to all objects.
+
+        n_threads
+            The number of threads the PackBuilder will spawn. If set to 0 libgit2 will autodetect the number of CPUs.
+        """
+
+        def pack_all_objects(pack_builder):
+            for obj in self.odb:
+                pack_builder.add(obj)
+
+        pack_delegate = pack_delegate or pack_all_objects
+
+        builder = PackBuilder(self)
+        if n_threads is not None:
+            builder.set_threads(n_threads)
+        pack_delegate(builder)
+        builder.write(path=path)
+
+        return builder.written_objects_count
+
+
     def __iter__(self):
         return iter(self.odb)
 
@@ -222,7 +256,7 @@ class BaseRepository(_Repository):
     #
     # References
     #
-    def create_reference(self, name, target, force=False):
+    def create_reference(self, name, target, force=False, message=None):
         """Create a new reference "name" which points to an object or to
         another reference.
 
@@ -231,10 +265,13 @@ class BaseRepository(_Repository):
 
         Keyword arguments:
 
-        force
+        force: bool
             If True references will be overridden, otherwise (the default) an
             exception is raised.
 
+        message: str
+            Optional message to use for the reflog.
+
         Examples::
 
             repo.create_reference('refs/heads/foo', repo.head.target)
@@ -248,9 +285,11 @@ class BaseRepository(_Repository):
                 and GIT_OID_MINPREFIXLEN <= len(target) <= GIT_OID_HEXSZ))
 
         if direct:
-            return self.create_reference_direct(name, target, force)
+            return self.create_reference_direct(name, target, force,
+                                                message=message)
 
-        return self.create_reference_symbolic(name, target, force)
+        return self.create_reference_symbolic(name, target, force,
+                                              message=message)
 
     def resolve_refish(self, refish):
         """Convert a reference-like short name "ref-ish" to a valid
